@@ -23,10 +23,11 @@ class HostsManager(surveil_manager.SurveilManager):
         super(HostsManager, self).__init__(http_client)
         self.metrics = metrics.MetricsManager(self.http_client)
 
-    def list(self, live_query={'filters': '{}'}):
+    def list(self, query=None):
         """Get a list of hosts."""
+        query = query or {}
         resp, body = self.http_client.json_request(
-            HostsManager.base_url, 'POST', body=live_query
+            HostsManager.base_url, 'POST', body=query
         )
         return body
 
@@ -36,3 +37,11 @@ class HostsManager(surveil_manager.SurveilManager):
             HostsManager.base_url + "/" + host_name, 'GET'
         )
         return body
+
+    def submit_check_result(self, host_name, **kwargs):
+        """Submit a check result."""
+        resp, body = self.http_client.json_request(
+            HostsManager.base_url + '/' + host_name + '/results', 'POST',
+            body=kwargs
+        )
+        return body
